tisdb.api module — tisdb 0.0.1.dev0 documentation

# tisdb.api module

class tisdb.api.TsdbApi(store_type: tisdb.types.StoreType, config: tisdb.config.TsdbConfig)

  Bases: `object`

  activate()
  insert_ignore(value: tisdb.model.TsdbData) → tisdb.model.TsdbData
  insert_ignore_batch(value: List[tisdb.model.TsdbData]) → List[tisdb.model.TsdbData]
  upsert(value: tisdb.model.TsdbData) → tisdb.model.TsdbData
  upsert_batch(value: List[tisdb.model.TsdbData]) → List[tisdb.model.TsdbData]